@@ -8,9 +8,11 @@ import weakref
 
 from collections import OrderedDict
 
-from .utils import escapeQuotes, tostr
+from .utils import escapeQuotes, tostr, isstr, stripWordsOnly
+from .conversions import convertToBooleanString
+from .constants import TAG_ITEM_BINARY_ATTRIBUTES_STRING_ATTR
 
-__all__ = ('SpecialAttributesDict', 'AttributeNode', 'AttributeNodeMap', 'StyleAttribute' )
+__all__ = ('SpecialAttributesDict', 'AttributeNode', 'AttributeNodeMap', 'StyleAttribute', 'DOMTokenList' )
 
 
 class SpecialAttributesDict(dict):
@@ -58,18 +60,48 @@ class SpecialAttributesDict(dict):
 
 
     def __getitem__(self, key):
+        key = key.lower()
+
         if key == 'style':
             # TODO: If detatched from a tag, this will throw an error.
             #         Need to handle detatch and reattach for this attribute
             return self.tag.style
         elif key == 'class':
             return self.tag.className
+        elif key in TAG_ITEM_BINARY_ATTRIBUTES_STRING_ATTR:
+            try:
+                val = dict.__getitem__(self, key)
+            except:
+                val = None
+
+            return convertToBooleanString(val)
 
         try:
             return dict.__getitem__(self, key)
         except KeyError:
             return None #  TODO: support undefined?
 
+    def __setitem__(self, key, value):
+        
+        key = key.lower()
+
+        tag = self.tag
+
+        if key == 'style':
+            if not isinstance(value, StyleAttribute):
+                tag.style = StyleAttribute(value, tag)
+            else:
+                tag.style = value
+        elif key == 'class':
+            # The setter for className will perform necessary stripping
+            tag.className = value
+            return
+        elif key in TAG_ITEM_BINARY_ATTRIBUTES_STRING_ATTR:
+            value = convertToBooleanString(value)
+
+        dict.__setitem__(self, key,  value)
+
+        return value
 
     def __delitem__(self, key):
         '''
@@ -77,6 +109,9 @@ class SpecialAttributesDict(dict):
 
                 @param key <str> - The attribute key to delete
         '''
+        
+        key = key.lower()
+
         if key == 'style':
             self.tag.style = ''
             return
@@ -92,6 +127,9 @@ class SpecialAttributesDict(dict):
 
     def __contains__(self, key):
         # Hack in 'class' here
+
+        key = key.lower()
+
         if key == 'class':
             return bool( len(self.tag._classNames) > 0 )
 
@@ -156,6 +194,9 @@ class SpecialAttributesDict(dict):
 
              @return - The value of attribute at #key, or #default if not present.
         '''
+
+        key = key.lower()
+
         if key == 'class':
             return self.tag.className
 
@@ -185,23 +226,6 @@ class SpecialAttributesDict(dict):
         except:
             pass
 
-    def __setitem__(self, key, value):
-        
-        tag = self.tag
-
-        if key == 'style':
-            if not isinstance(value, StyleAttribute):
-                tag.style = StyleAttribute(value, tag)
-            else:
-                tag.style = value
-        elif key == 'class':
-            # The setter for className will perform necessary stripping
-            tag.className = value
-            return
-
-        dict.__setitem__(self, key,  value)
-
-        return value
 
     def __repr__(self):
         self._handleClassAttr()
@@ -776,4 +800,43 @@ class StyleAttribute(object):
         return self.__class__(self._asStr())
 
 
+class DOMTokenList(list):
+    '''
+        DOMTokenList - Imitates a DOMTokenList, that is a list in normal form, but joins via " " on stringifying
+
+                and can be constructed from a string by stripping to single words and splitting by " ", ignoring empty string case
+    '''
+
+    def __init__(self, *args, **kwargs):
+        '''
+            __init__ - Create a DOMTaskList.
+
+                Can take no arguments to create empty list
+
+                Can take a list argument to use those elements in this list
+
+                Can take a string argument, and will strip whitespace and retain each distinct word as an element
+        '''
+        if len(args) == 1 and isstr(args[0]):
+            strippedValue = stripWordsOnly(args[0])
+            if not strippedValue:
+                # Empty string, don't try to split (we would get one empty string element)
+                return list.__init__(self)
+            # Create list with split string
+            return list.__init__(self, strippedValue.split(' '))
+
+        return list.__init__(self, *args, **kwargs)
+
+
+    def __str__(self):
+        '''
+            __str__ - String this element. Equivilant to a javascript DOMTokenList.toString(),
+                
+                and will join by ' '
+        '''
+        return ' '.join(self)
+
+    def __repr__(self):
+        return 'DOMTokenList(%s)' %( list.__repr__(self), )
+
 #vim: set ts=4 sw=4 expandtab :
